resource "kubernetes_daemonset" "kube2iam_daemonset" {
  metadata {
    name      = "kube2iam"
    namespace = "kube-system"

    labels {
      app = "kube2iam"
    }
  }

  spec {
    selector {
      match_labels {
        app = "kube2iam"
      }
    }

    template {
      metadata {
        name = "kube2iam"

        labels {
          app = "kube2iam"
        }
      }

      spec {
        service_account_name = "kube2iam-svc-acc"
        host_network         = true

        volume {
          name = "${kubernetes_service_account.kube2iam_service_account.default_secret_name}"

          secret {
            secret_name = "${kubernetes_service_account.kube2iam_service_account.default_secret_name}"
          }
        }


        container {
          image             = "jtblin/kube2iam:0.10.4"
          name              = "kube2iam-container"
          image_pull_policy = "IfNotPresent"

          args = ["--host-interface=eni+", "--default-role=eks-kube2iam-default-role", "--use-regional-sts-endpoint", "--iptables=true", "--auto-discover-base-arn", "--app-port=8181", "--host-ip=$(HOST_IP)"]

          volume_mount {
            mount_path = "/var/run/secrets/kubernetes.io/serviceaccount"
            name       = "${kubernetes_service_account.kube2iam_service_account.default_secret_name}"
            read_only  = true
          }
          security_context {
            privileged = "true"
          }

          env {
            name = "HOST_IP"

            value_from = {
              field_ref = {
                field_path = "status.podIP"
              }
            }
          }

          resources {
            limits {
              cpu    = "0.5"
              memory = "512Mi"
            }

            requests {
              cpu    = "250m"
              memory = "50Mi"
            }
          }
        }
      }
    }
  }
}
